@@ -1,24 +1,27 @@
 package WebService::Bloglines::Entries;
 
 use vars qw($VERSION);
-$VERSION = 0.01;
+$VERSION = 0.07;
 
 use strict;
-use XML::RSS;
-use XML::XPath;
+use XML::RSS::LibXML;
+use XML::LibXML;
 use HTML::Entities;
 
 sub parse {
     my($class, $xml) = @_;
-    my $xp = XML::XPath->new(ioref => $xml);
-    my $rssparent = $xp->find("/rss")->get_node(0);
-    my $channelnode = $xp->find("/rss/channel");
+
+    my $parser = XML::LibXML->new;
+    my $doc    = $parser->parse_string($xml);
+    my $rssparent   = $doc->find("/rss")->get_node(0);
+    my $channelnode = $doc->find("/rss/channel");
+    $rssparent->removeChildNodes();
 
     my @entries;
     for my $node ($channelnode->get_nodelist()) {
-	my $xml = $rssparent->toString(1); # norecurse
+	my $xml = $rssparent->toString();
 	my $channel = $node->toString();
-	$xml =~ s!</rss>$!\n$channel\n</rss>!; # wooh
+	$xml =~ s!<(rss.*?)/>$!<$1>\n$channel\n</rss>!; # wooh
 	push @entries, $class->new($xml);
     }
     return wantarray ? @entries : $entries[0];
@@ -36,7 +39,7 @@ sub new {
 sub _parse_xml {
     my $self = shift;
 
-    my $rss = XML::RSS->new();
+    my $rss = XML::RSS::LibXML->new();
     $rss->add_module(prefix => "bloglines", uri => "http://www.bloglines.com/services/module");
     $rss->parse($self->{_xml});
     $self->{_rss} = $rss;
